==> kubernetes-model-gatewayapi-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/ListenerFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ListenerFluent<A extends ListenerFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAllowedRoutes instead.
   * @return The buildable object.
   */
  @Deprecated
  public AllowedRoutes getAllowedRoutes();
  public AllowedRoutes buildAllowedRoutes();
  public A withAllowedRoutes(AllowedRoutes allowedRoutes);
  public Boolean hasAllowedRoutes();
  public ListenerFluent.AllowedRoutesNested<A> withNewAllowedRoutes();
  public ListenerFluent.AllowedRoutesNested<A> withNewAllowedRoutesLike(AllowedRoutes item);
  public ListenerFluent.AllowedRoutesNested<A> editAllowedRoutes();
  public ListenerFluent.AllowedRoutesNested<A> editOrNewAllowedRoutes();
  public ListenerFluent.AllowedRoutesNested<A> editOrNewAllowedRoutesLike(AllowedRoutes item);
  public String getHostname();
  public A withHostname(String hostname);
  public Boolean hasHostname();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public String getProtocol();
  public A withProtocol(String protocol);
  public Boolean hasProtocol();
  
  /**
   * This method has been deprecated, please use method buildTls instead.
   * @return The buildable object.
   */
  @Deprecated
  public GatewayTLSConfig getTls();
  public GatewayTLSConfig buildTls();
  public A withTls(GatewayTLSConfig tls);
  public Boolean hasTls();
  public ListenerFluent.TlsNested<A> withNewTls();
  public ListenerFluent.TlsNested<A> withNewTlsLike(GatewayTLSConfig item);
  public ListenerFluent.TlsNested<A> editTls();
  public ListenerFluent.TlsNested<A> editOrNewTls();
  public ListenerFluent.TlsNested<A> editOrNewTlsLike(GatewayTLSConfig item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AllowedRoutesNested<N> extends Nested<N>,AllowedRoutesFluent<ListenerFluent.AllowedRoutesNested<N>>{
    public N and();
    public N endAllowedRoutes();
    
  }
  public interface TlsNested<N> extends Nested<N>,GatewayTLSConfigFluent<ListenerFluent.TlsNested<N>>{
    public N and();
    public N endTls();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/ListenerFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ListenerFluent<A extends ListenerFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAllowedRoutes instead.
   * @return The buildable object.
   */
  @Deprecated
  public AllowedRoutes getAllowedRoutes();
  public AllowedRoutes buildAllowedRoutes();
  public A withAllowedRoutes(AllowedRoutes allowedRoutes);
  public Boolean hasAllowedRoutes();
  public ListenerFluent.AllowedRoutesNested<A> withNewAllowedRoutes();
  public ListenerFluent.AllowedRoutesNested<A> withNewAllowedRoutesLike(AllowedRoutes item);
  public ListenerFluent.AllowedRoutesNested<A> editAllowedRoutes();
  public ListenerFluent.AllowedRoutesNested<A> editOrNewAllowedRoutes();
  public ListenerFluent.AllowedRoutesNested<A> editOrNewAllowedRoutesLike(AllowedRoutes item);
  public String getHostname();
  public A withHostname(String hostname);
  public Boolean hasHostname();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public String getProtocol();
  public A withProtocol(String protocol);
  public Boolean hasProtocol();
  
  /**
   * This method has been deprecated, please use method buildTls instead.
   * @return The buildable object.
   */
  @Deprecated
  public GatewayTLSConfig getTls();
  public GatewayTLSConfig buildTls();
  public A withTls(GatewayTLSConfig tls);
  public Boolean hasTls();
  public ListenerFluent.TlsNested<A> withNewTls();
  public ListenerFluent.TlsNested<A> withNewTlsLike(GatewayTLSConfig item);
  public ListenerFluent.TlsNested<A> editTls();
  public ListenerFluent.TlsNested<A> editOrNewTls();
  public ListenerFluent.TlsNested<A> editOrNewTlsLike(GatewayTLSConfig item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AllowedRoutesNested<N> extends Nested<N>,AllowedRoutesFluent<ListenerFluent.AllowedRoutesNested<N>>{
    public N and();
    public N endAllowedRoutes();
    
  }
  public interface TlsNested<N> extends Nested<N>,GatewayTLSConfigFluent<ListenerFluent.TlsNested<N>>{
    public N and();
    public N endTls();
    
  }
  
}
